@@ -42,6 +42,7 @@ enum
 	OPEN_URI,
 	SIZE_TO,
 	DOM_MOUSE_CLICK,
+	DOM_MOUSE_DOWN,
 	SECURITY_CHANGE,
 	ZOOM_CHANGE,
 	LAST_SIGNAL
@@ -230,6 +231,16 @@ ephy_embed_base_init (gpointer g_class)
                               G_TYPE_INT,
                               1,
 			      G_TYPE_POINTER);
+	ephy_embed_signals[DOM_MOUSE_DOWN] =
+                g_signal_new ("ge_dom_mouse_down",
+                              EPHY_EMBED_TYPE,
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (EphyEmbedClass, dom_mouse_down),
+                              NULL, NULL,
+                              ephy_marshal_INT__OBJECT,
+                              G_TYPE_INT,
+                              1,
+			      G_TYPE_POINTER);
 	ephy_embed_signals[SECURITY_CHANGE] =
                 g_signal_new ("ge_security_change",
                               EPHY_EMBED_TYPE,
