@@ -22,11 +22,8 @@
 
 #include "ContentHandler.h"
 #include "FilePicker.h"
-#include "FtpProtocolHandler.h"
-#include "StartHereProtocolHandler.h"
 #include "GlobalHistory.h"
-#include "IRCProtocolHandler.h"
-#include "MailtoProtocolHandler.h"
+#include "ExternalProtocolHandlers.h"
 #include "PrintingPromptService.h"
 #include "ProgressListener.h"
 #include "ExternalProtocolService.h"
@@ -40,7 +37,6 @@
 #include <glib.h>
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutRedirector)
-NS_GENERIC_FACTORY_CONSTRUCTOR(GStartHereProtocolHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GProgressListener)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GContentHandler)
@@ -48,6 +44,7 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GIRCProtocolHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFtpProtocolHandler)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GNewsProtocolHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GExternalProtocolService)
 
 static const nsModuleComponentInfo sAppComps[] = {
@@ -105,18 +102,24 @@ static const nsModuleComponentInfo sAppComps[] = {
 		G_IRC_CONTENT_CONTRACTID,
 		GIRCProtocolHandlerConstructor
 	},
+	{
+		G_NEWS_PROTOCOL_CLASSNAME,
+		G_NEWS_PROTOCOL_CID,
+		G_NEWS_PROTOCOL_CONTRACTID,
+		GNewsProtocolHandlerConstructor
+	},
+	{
+		G_NEWS_CONTENT_CLASSNAME,
+		G_NEWS_PROTOCOL_CID,
+		G_NEWS_CONTENT_CONTRACTID,
+		GNewsProtocolHandlerConstructor
+	},
 	{
 		G_FTP_CONTENT_CLASSNAME,
 		G_FTP_PROTOCOL_CID,
 		G_FTP_CONTENT_CONTRACTID,
 		GFtpProtocolHandlerConstructor
 	},
-	{
-		G_START_HERE_PROTOCOLHANDLER_CLASSNAME,
-		G_START_HERE_PROTOCOLHANDLER_CID,
-		G_START_HERE_PROTOCOLHANDLER_CONTRACTID,
-		GStartHereProtocolHandlerConstructor
-	},
 	{
 		EPHY_ABOUT_REDIRECTOR_CLASSNAME,
 		EPHY_ABOUT_REDIRECTOR_CID,
@@ -181,13 +184,11 @@ static const nsModuleComponentInfo sModuleComps[] = {
 
 static NS_DEFINE_CID(knsFtpProtocolHandlerCID, NS_FTPPROTOCOLHANDLER_CID);
 
-//Annoying globals to track the mozilla ftp handler so it can be restored.
+/* Annoying globals to track the mozilla ftp handler so it can be restored. */
 static PRBool ftpRegistered = PR_FALSE;
 static nsCOMPtr<nsIFactory> nsFtpFactory;
 
-/* FIXME why we need to use "C" here ???? */
-
-extern  "C" gboolean
+gboolean
 mozilla_register_components (void)
 {
 	gboolean ret = TRUE;
@@ -222,7 +223,8 @@ mozilla_register_components (void)
 /**
  * mozilla_register_FtpProtocolHandler: Register Ftp Protocol Handler
  */
-extern "C" gboolean mozilla_register_FtpProtocolHandler (void)
+gboolean
+mozilla_register_FtpProtocolHandler (void)
 {
 	if (ftpRegistered == PR_TRUE) return TRUE;
 
@@ -259,7 +261,8 @@ extern "C" gboolean mozilla_register_FtpProtocolHandler (void)
 /**
  * mozilla_unregister_FtpProtocolHandler: Unregister Ftp Protocol Handler
  */
-extern "C" gboolean mozilla_unregister_FtpProtocolHandler (void)
+gboolean
+mozilla_unregister_FtpProtocolHandler (void)
 {
 	if (ftpRegistered == PR_FALSE) return FALSE;
         
@@ -281,7 +284,7 @@ extern "C" gboolean mozilla_unregister_FtpProtocolHandler (void)
 /**
  * mozilla_register_MailtoProtocolHandler: Register Mailto Protocol Handler
  */
-extern "C" gboolean 
+gboolean 
 mozilla_register_MailtoProtocolHandler (void)
 {
 	gboolean retVal = TRUE;
