@@ -55,7 +55,7 @@ struct _EggMenuMergeClass {
 struct _EggMenuMergeNode {
   EggMenuMergeNodeType type;
 
-  const gchar *name;
+  gchar *name;
 
   GQuark action_name;
   EggAction *action;
@@ -86,7 +86,7 @@ GtkWidget    *egg_menu_merge_get_widget          (EggMenuMerge *self,
  * interface */
 guint         egg_menu_merge_add_ui_from_string  (EggMenuMerge *self,
 						  const gchar *buffer,
-						  glong length,
+						  size_t length,
 						  GError **error);
 guint         egg_menu_merge_add_ui_from_file    (EggMenuMerge *self,
 						  const gchar *filename,
