@@ -24,6 +24,7 @@
 
 #include <gtk/gtkbin.h>
 #include <gtk/gtktooltips.h>
+#include <gtk/gtkmenuitem.h>
 
 #define EGG_TYPE_TOOL_ITEM            (egg_tool_item_get_type ())
 #define EGG_TOOL_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EGG_TYPE_TOOL_ITEM, EggToolItem))
@@ -51,46 +52,56 @@ struct _EggToolItem
   guint pack_end : 1;
   guint use_drag_window : 1;
   guint overflow_item : 1;
+
+  GtkWidget *menu_item;
+  gchar *menu_item_id;
 };
 
 struct _EggToolItemClass
 {
   GtkBinClass parent_class;
 
-  GtkWidget *(* create_menu_proxy)   (EggToolItem    *tool_item);
-  void       (* toolbar_reconfigured) (EggToolItem   *tool_item);
-  void	     (* set_tooltip)	     (EggToolItem    *tool_item,
-				      GtkTooltips    *tooltips,
-				      const gchar    *tip_text,
-				      const gchar    *tip_private);
+  /* signals */
+  gboolean   (* create_menu_proxy)    (EggToolItem *tool_item);
+  void       (* toolbar_reconfigured) (EggToolItem *tool_item);
+  gboolean   (* set_tooltip)	      (EggToolItem *tool_item,
+				       GtkTooltips *tooltips,
+				       const gchar *tip_text,
+				       const gchar *tip_private);
 };
 
 GType        egg_tool_item_get_type (void);
 EggToolItem *egg_tool_item_new      (void);
 
-void            egg_tool_item_toolbar_reconfigured   (EggToolItem     *tool_item);
-void            egg_tool_item_set_homogeneous        (EggToolItem     *tool_item,
-						      gboolean         homogeneous);
-void            egg_tool_item_set_expand             (EggToolItem     *tool_item,
-						      gboolean         expand);
-void            egg_tool_item_set_pack_end           (EggToolItem     *tool_item,
-						      gboolean         pack_end);
-void            egg_tool_item_set_tooltip            (EggToolItem     *tool_item,
-						      GtkTooltips     *tooltips,
-						      const gchar     *tip_text,
-						      const gchar     *tip_private);
-void            egg_tool_item_set_use_drag_window    (EggToolItem     *toolitem,
-						      gboolean         use_drag_window);
-void            egg_tool_item_set_visible_horizontal (EggToolItem     *toolitem,
-						      gboolean         visible_horizontal);
-gboolean        egg_tool_item_get_visible_horizontal (EggToolItem     *toolitem);
-void            egg_tool_item_set_visible_vertical   (EggToolItem     *toolitem,
-						      gboolean         visible_horizontal);
-gboolean        egg_tool_item_get_visible_vertical   (EggToolItem     *toolitem);
-GtkIconSize     egg_tool_item_get_icon_size          (EggToolItem     *tool_item);
-GtkOrientation  egg_tool_item_get_orientation        (EggToolItem     *tool_item);
-GtkToolbarStyle egg_tool_item_get_toolbar_style      (EggToolItem     *tool_item);
-GtkReliefStyle  egg_tool_item_get_relief_style       (EggToolItem     *tool_item);
+void            egg_tool_item_toolbar_reconfigured     (EggToolItem *tool_item);
+void            egg_tool_item_set_homogeneous          (EggToolItem *tool_item,
+							gboolean     homogeneous);
+void            egg_tool_item_set_expand               (EggToolItem *tool_item,
+							gboolean     expand);
+void            egg_tool_item_set_pack_end             (EggToolItem *tool_item,
+							gboolean     pack_end);
+void            egg_tool_item_set_tooltip              (EggToolItem *tool_item,
+							GtkTooltips *tooltips,
+							const gchar *tip_text,
+							const gchar *tip_private);
+void            egg_tool_item_set_use_drag_window      (EggToolItem *toolitem,
+							gboolean     use_drag_window);
+void            egg_tool_item_set_visible_horizontal   (EggToolItem *toolitem,
+							gboolean     visible_horizontal);
+gboolean        egg_tool_item_get_visible_horizontal   (EggToolItem *toolitem);
+void            egg_tool_item_set_visible_vertical     (EggToolItem *toolitem,
+							gboolean     visible_horizontal);
+gboolean        egg_tool_item_get_visible_vertical     (EggToolItem *toolitem);
+GtkIconSize     egg_tool_item_get_icon_size            (EggToolItem *tool_item);
+GtkOrientation  egg_tool_item_get_orientation          (EggToolItem *tool_item);
+GtkToolbarStyle egg_tool_item_get_toolbar_style        (EggToolItem *tool_item);
+GtkReliefStyle  egg_tool_item_get_relief_style         (EggToolItem *tool_item);
+GtkWidget *     egg_tool_item_retrieve_proxy_menu_item (EggToolItem *tool_item);
+GtkWidget *     egg_tool_item_get_proxy_menu_item      (EggToolItem *tool_item,
+							const gchar *menu_item_id);
+void            egg_tool_item_set_proxy_menu_item      (EggToolItem *tool_item,
+							const gchar *menu_item_id,
+							GtkWidget   *menu_item);
 
 
 #endif /* __EGG_TOOL_ITEM_H__ */
