@@ -21,9 +21,11 @@
 #endif
 
 #include <bonobo/bonobo-i18n.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
 
 #include "ephy-bookmark-action.h"
 #include "ephy-bookmarks.h"
+#include "ephy-favicon-cache.h"
 #include "ephy-shell.h"
 #include "ephy-string.h"
 #include "eggtoolitem.h"
@@ -38,7 +40,7 @@ struct EphyBookmarkActionPrivate
 {
 	int bookmark_id;
 	char *location;
-	char *smart_url;
+	gboolean smart_url;
 	char *icon;
 };
 
@@ -88,24 +90,12 @@ ephy_bookmark_action_get_type (void)
 	return type;
 }
 
-static GtkWidget *
-create_menu_item (EggAction *action)
-{
-	GtkWidget *item;
-
-	item = gtk_image_menu_item_new ();
-
-	return item;
-}
-
 static GtkWidget *
 create_tool_item (EggAction *action)
 {
-	GtkWidget *item;
-	GtkWidget *button;
-	GtkWidget *hbox;
-	GtkWidget *label;
-	GtkWidget *icon;
+	GtkWidget *item, *button, *hbox, *label, *icon, *entry;
+
+	LOG ("Creating tool item for action %p", action)
 
 	item = (* EGG_ACTION_CLASS (parent_class)->create_tool_item) (action);
 
@@ -119,16 +109,10 @@ create_tool_item (EggAction *action)
 	gtk_container_add (GTK_CONTAINER (hbox), button);
 	g_object_set_data (G_OBJECT (item), "button", button);
 
-	if (EPHY_BOOKMARK_ACTION (action)->priv->smart_url)
-	{
-		GtkWidget *entry;
-
-		entry = gtk_entry_new ();
-		gtk_widget_set_size_request (entry, 120, -1);
-		gtk_widget_show (entry);
-		gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
-		g_object_set_data (G_OBJECT (item), "entry", entry);
-	}
+	entry = gtk_entry_new ();
+	gtk_widget_set_size_request (entry, 120, -1);
+	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+	g_object_set_data (G_OBJECT (item), "entry", entry);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
@@ -147,6 +131,28 @@ create_tool_item (EggAction *action)
 	return item;
 }
 
+static void
+ephy_bookmark_action_sync_smart_url (EggAction *action, GParamSpec *pspec, GtkWidget *proxy)
+{
+	if (EGG_IS_TOOL_ITEM (proxy))
+	{
+		GtkWidget *entry;
+		gboolean smart_url;
+
+		smart_url = EPHY_BOOKMARK_ACTION (action)->priv->smart_url;
+		entry = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "entry"));
+
+		if (smart_url)
+		{
+			gtk_widget_show (entry);
+		}
+		else
+		{
+			gtk_widget_hide (entry);
+		}
+	}
+}
+
 static void
 ephy_bookmark_action_sync_icon (EggAction *action, GParamSpec *pspec, GtkWidget *proxy)
 {
@@ -156,8 +162,8 @@ ephy_bookmark_action_sync_icon (EggAction *action, GParamSpec *pspec, GtkWidget
 
 	icon_location = EPHY_BOOKMARK_ACTION (action)->priv->icon;
 
-	cache = ephy_embed_shell_get_favicon_cache
-		(EPHY_EMBED_SHELL (ephy_shell));
+	cache = EPHY_FAVICON_CACHE (ephy_embed_shell_get_favicon_cache
+		(EPHY_EMBED_SHELL (ephy_shell)));
 
 	if (icon_location)
 	{
@@ -200,7 +206,8 @@ ephy_bookmark_action_sync_label (EggAction *action, GParamSpec *pspec, GtkWidget
 
 	title = ephy_string_shorten (action->label, MAX_LABEL_LENGTH);
 
-	if (EPHY_BOOKMARK_ACTION (action)->priv->smart_url)
+	if (EPHY_BOOKMARK_ACTION (action)->priv->smart_url
+	    && EGG_IS_TOOL_ITEM (proxy))
 	{
 		label_text = g_strdup_printf (_("%s:"), title);
 	}
@@ -231,41 +238,88 @@ ephy_bookmark_action_sync_label (EggAction *action, GParamSpec *pspec, GtkWidget
 }
 
 static void
-entry_activated_cb (GtkWidget *entry, EggAction *action)
+activate_cb (GtkWidget *widget, EggAction *action)
 {
-	char *text;
-	char *solved;
-	char *smart_url;
-	EphyBookmarks *bookmarks;
+	char *location = NULL;
+	char *text = NULL;
 
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+	if (GTK_IS_EDITABLE (widget))
+	{
+		text = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
+	}
 
-	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-	if (text == NULL) return;
+	if (text != NULL && text[0] != '\0')
+	{
+		char *smart_url;
+		EphyBookmarks *bookmarks;
+
+		bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+
+		smart_url = EPHY_BOOKMARK_ACTION (action)->priv->location;
+		location = ephy_bookmarks_solve_smart_url (bookmarks,
+							   smart_url,
+							   text);
+	}
+	else
+	{
+		EphyBookmarkAction *baction = EPHY_BOOKMARK_ACTION (action);
+
+		if (baction->priv->smart_url)
+		{
+			GnomeVFSURI *uri;
+
+			uri = gnome_vfs_uri_new (baction->priv->location);
+
+			if (uri)
+			{
+				location = g_strdup (gnome_vfs_uri_get_host_name (uri));
+				gnome_vfs_uri_unref (uri);
+			}
+		}
+
+		if (location == NULL)
+		{
+			location = g_strdup (baction->priv->location);
+		}
+	}
 
-	smart_url = EPHY_BOOKMARK_ACTION (action)->priv->smart_url;
-	solved = ephy_bookmarks_solve_smart_url (bookmarks,
-						 smart_url,
-						 text);
 	g_signal_emit (action,
 		       ephy_bookmark_action_signals[GO_LOCATION],
-		       0, solved);
+		       0, location);
 
+	g_free (location);
 	g_free (text);
 }
 
-static void
-activate_cb (GtkWidget *widget, EggAction *action)
+static gboolean
+create_menu_proxy (EggToolItem *item, EggAction *action)
 {
-	g_signal_emit (action,
-		       ephy_bookmark_action_signals[GO_LOCATION],
-		       0, EPHY_BOOKMARK_ACTION (action)->priv->location);
+	EphyBookmarkAction *bm_action = EPHY_BOOKMARK_ACTION (action);
+	GtkWidget *menu_item;
+	char *menu_id;
+
+	LOG ("create_menu_proxy item %p, action %p", item, action);
+
+	menu_item = EGG_ACTION_GET_CLASS (action)->create_menu_item (action);
+
+	EGG_ACTION_GET_CLASS (action)->connect_proxy (action, menu_item);
+
+	menu_id = g_strdup_printf ("ephy-bookmark-action-%d-menu-id",
+				   bm_action->priv->bookmark_id);
+
+	egg_tool_item_set_proxy_menu_item (item, menu_id, menu_item);
+
+	g_free (menu_id);
+
+	return TRUE;	
 }
 
 static void
 connect_proxy (EggAction *action, GtkWidget *proxy)
 {
-	GtkWidget *button;
+	GtkWidget *button, *entry;
+
+	LOG ("Connecting action %p to proxy %p", action, proxy)
 
 	(* EGG_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
 
@@ -277,24 +331,24 @@ connect_proxy (EggAction *action, GtkWidget *proxy)
 	g_signal_connect_object (action, "notify::icon",
 			         G_CALLBACK (ephy_bookmark_action_sync_icon), proxy, 0);
 
+	ephy_bookmark_action_sync_smart_url (action, NULL, proxy);
+	g_signal_connect_object (action, "notify::smarturl",
+			         G_CALLBACK (ephy_bookmark_action_sync_smart_url), proxy, 0);
+
 	if (EGG_IS_TOOL_ITEM (proxy))
 	{
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "clicked", G_CALLBACK (activate_cb), action);
+
+		entry = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "entry"));
+		g_signal_connect (entry, "activate", G_CALLBACK (activate_cb), action);
+
+		g_signal_connect (proxy, "create_menu_proxy", G_CALLBACK (create_menu_proxy), action);
 	}
 	else if (GTK_IS_MENU_ITEM (proxy))
 	{
 		g_signal_connect (proxy, "activate", G_CALLBACK (activate_cb), action);
 	}
-
-	if (EPHY_BOOKMARK_ACTION (action)->priv->smart_url &&
-	    EGG_IS_TOOL_ITEM (proxy))
-	{
-		GtkWidget *entry;
-
-		entry = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "entry"));
-		g_signal_connect (entry, "activate", G_CALLBACK (entry_activated_cb), action);
-	}
 }
 
 static void
@@ -317,13 +371,13 @@ ephy_bookmark_action_set_property (GObject *object,
 			bmk->priv->location = g_strdup (g_value_get_string (value));
 			break;
 		case PROP_SMART_URL:
-			g_free (bmk->priv->smart_url);
-			bmk->priv->smart_url = g_strdup (g_value_get_string (value));
+			bmk->priv->smart_url = g_value_get_boolean (value);
+			g_object_notify (object, "smarturl");
 			break;
 		case PROP_ICON:
 			g_free (bmk->priv->icon);
 			bmk->priv->icon = g_strdup (g_value_get_string (value));
-			g_object_notify(object, "icon");
+			g_object_notify (object, "icon");
 			break;
 	}
 }
@@ -358,7 +412,6 @@ ephy_bookmark_action_finalize (GObject *object)
         g_return_if_fail (eba->priv != NULL);
 
 	g_free (eba->priv->location);
-	g_free (eba->priv->smart_url);
 	g_free (eba->priv->icon);
 
         g_free (eba->priv);
@@ -379,7 +432,7 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 
 	action_class->toolbar_item_type = EGG_TYPE_TOOL_ITEM;
 	action_class->create_tool_item = create_tool_item;
-	action_class->create_menu_item = create_menu_item;
+	action_class->menu_item_type = GTK_TYPE_IMAGE_MENU_ITEM;
 	action_class->connect_proxy = connect_proxy;
 
 	object_class->finalize = ephy_bookmark_action_finalize;
@@ -415,11 +468,11 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
                                                                G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
                                          PROP_SMART_URL,
-                                         g_param_spec_string  ("smart_url",
-                                                               "Smart url",
-                                                               "Smart url",
-                                                               NULL,
-                                                               G_PARAM_READWRITE));
+                                         g_param_spec_boolean  ("smarturl",
+                                                                "Smart url",
+                                                                "Smart url",
+                                                                FALSE,
+                                                                G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
                                          PROP_ICON,
                                          g_param_spec_string  ("icon",
@@ -432,7 +485,8 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 static void
 sync_bookmark_properties (EggAction *action, EphyNode *bmk)
 {
-	const char *title, *location, *smart_url, *icon;
+	const char *title, *location, *icon;
+	gboolean smart_url;
 
 	icon = ephy_node_get_property_string
 		(bmk, EPHY_NODE_BMK_PROP_ICON);
@@ -440,14 +494,13 @@ sync_bookmark_properties (EggAction *action, EphyNode *bmk)
 		(bmk, EPHY_NODE_BMK_PROP_TITLE);
 	location = ephy_node_get_property_string
 		(bmk, EPHY_NODE_BMK_PROP_LOCATION);
-	smart_url = ephy_node_get_property_string
-		(bmk, EPHY_NODE_BMK_PROP_SMART_LOCATION);
-	if (smart_url && *smart_url == '\0') smart_url = NULL;
+	smart_url = ephy_node_get_property_boolean
+		(bmk, EPHY_NODE_BMK_PROP_HAS_SMART_ADDRESS);
 
 	g_object_set (action,
 		      "label", title,
 		      "location", location,
-		      "smart_url", smart_url,
+		      "smarturl", smart_url,
 		      "icon", icon,
 		      NULL);
 }
@@ -474,7 +527,6 @@ ephy_bookmark_action_init (EphyBookmarkAction *action)
 	action->priv = g_new0 (EphyBookmarkActionPrivate, 1);
 
 	action->priv->location = NULL;
-	action->priv->smart_url = NULL;
 	action->priv->icon = NULL;
 
 
