@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2001, 2002 Ricardo Fernndez Pascual
+ *  Copyright (C) 2001, 2002 Ricardo Fernández Pascual
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,17 +22,18 @@
 #include <bonobo/bonobo-zoomable.h>
 #include <bonobo/bonobo-ui-util.h>
 #include <string.h>
+
 #include "ephy-embed-popup-control.h"
 #include "ephy-nautilus-view.h"
 #include "ephy-embed.h"
 #include "ephy-embed-utils.h"
 #include "find-dialog.h"
 #include "print-dialog.h"
-#include "ephy-prefs.h"
-#include "eel-gconf-extensions.h"
+#include "ephy-zoom.h"
 #include "ephy-debug.h"
 
-static void		gnv_embed_location_cb 			(EphyEmbed *embed, 
+static void		gnv_embed_location_cb 			(EphyEmbed *embed,
+								 const char *new_uri,
 								 EphyNautilusView *view);
 static void		gnv_embed_title_cb 			(EphyEmbed *embed, 
 								 EphyNautilusView *view);
@@ -43,11 +44,14 @@ static void		gnv_embed_new_window_cb			(EphyEmbed *embed,
 static void		gnv_embed_link_message_cb 		(EphyEmbed *embed, 
 								 const char *message,
 								 EphyNautilusView *view);
-static gint		gnv_embed_dom_mouse_down_cb		(EphyEmbed *embed,
+static gint		gnv_embed_dom_mouse_click_cb		(EphyEmbed *embed,
+								 EphyEmbedEvent *event,
+								 EphyNautilusView *view);
+static void		gnv_embed_context_menu_cb		(EphyEmbed *embed,
 								 EphyEmbedEvent *event,
 								 EphyNautilusView *view);
 static void		gnv_embed_zoom_change_cb 		(EphyNautilusView *embed,
-								 guint new_zoom, 
+								 float new_zoom, 
 								 EphyNautilusView *view);
 
 
@@ -73,8 +77,8 @@ static void		gnv_zoomable_zoom_to_fit_cb		(BonoboZoomable *zoomable,
 static void		gnv_zoomable_zoom_to_default_cb		(BonoboZoomable *zoomable,
 								 EphyNautilusView *view);
 /* commands */
-static void		gnv_cmd_set_charset			(BonoboUIComponent *uic, 
-								 EncodingMenuData *data, 
+static void		gnv_cmd_set_encoding			(BonoboUIComponent *uic, 
+								 EphyNautilusView *view,
 								 const char* verbname);
 static void 		gnv_cmd_file_print			(BonoboUIComponent *uic, 
 								 EphyNautilusView *view, 
@@ -85,56 +89,24 @@ static void 		gnv_cmd_edit_find			(BonoboUIComponent *uic,
 
 
 /* popups */
-static EphyNautilusView *gnv_view_from_popup			(EphyEmbedPopup *popup);
+static EphyNautilusView *gnv_view_from_popup			(EphyEmbedPopupControl*popup);
 
 static void 		gnv_popup_cmd_new_window		(BonoboUIComponent *uic, 
-								 EphyEmbedPopup *popup, 
+								 EphyEmbedPopupControl*popup, 
 								 const char* verbname);
 static void 		gnv_popup_cmd_image_in_new_window	(BonoboUIComponent *uic, 
-								 EphyEmbedPopup *popup, 
+								 EphyEmbedPopupControl*popup, 
 								 const char* verbname);
 static void 		gnv_popup_cmd_frame_in_new_window	(BonoboUIComponent *uic, 
-								 EphyEmbedPopup *popup, 
+								 EphyEmbedPopupControl*popup, 
 								 const char* verbname);
 
-
-static float preferred_zoom_levels[] = {
-	0.2, 0.4, 0.6, 0.8,
-	1.0, 1.2, 1.4, 1.6, 1.8,
-	2.0, 2.2, 2.4, 2.6, 2.8,
-	3.0, 3.2, 3.4, 3.6, 3.8,
-	4.0, 4.2, 4.4, 4.6, 4.8,
-	5.0, 5.2, 5.4, 5.6, 5.8,
-	6.0, 6.2, 6.4, 6.6, 6.8,
-	7.0, 7.2, 7.4, 7.6, 7.8,
-	8.0, 8.2, 8.4, 8.6, 8.8,
-	9.0, 9.2, 9.4, 9.6, 9.8,
-};
-
-static const gchar *preferred_zoom_level_names[] = {
-	"20%", "40%", "60%", "80%",
-	"100%", "120%", "140%", "160%", "180%",
-	"200%", "220%", "240%", "260%", "280%",
-	"300%", "320%", "340%", "360%", "380%",
-	"400%", "420%", "440%", "460%", "480%",
-	"500%", "520%", "540%", "560%", "580%",
-	"600%", "620%", "640%", "660%", "680%",
-	"700%", "720%", "740%", "760%", "780%",
-	"800%", "820%", "840%", "860%", "880%",
-	"900%", "920%", "940%", "960%", "980%",
-};
-#define NUM_ZOOM_LEVELS (sizeof (preferred_zoom_levels) / sizeof (float))
-
 struct EphyNautilusViewPrivate {
 	EphyEmbed *embed;
 	char *title;
 	char *location;
 	int load_percent;
 
-	/*
-	  BonoboPropertyBag   *property_bag;
-	*/
-
 	EphyEmbedPopupControl *popup;
 	BonoboUIComponent *popup_ui;
 	BonoboControl *control;
@@ -158,7 +130,7 @@ BonoboUIVerb ephy_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-#define CHARSET_MENU_PATH "/menu/View/Encoding"
+#define ENCODING_MENU_PATH "/menu/View/Encoding"
 
 
 BONOBO_CLASS_BOILERPLATE (EphyNautilusView, ephy_nautilus_view,
@@ -170,6 +142,9 @@ ephy_nautilus_view_instance_init (EphyNautilusView *view)
 	GtkWidget *w;
 	EphyNautilusViewPrivate *p = g_new0 (EphyNautilusViewPrivate, 1);
 	EphyEmbedSingle *single;
+	float *levels;
+	gchar **names;
+	guint i;
 
 	single = ephy_embed_shell_get_embed_single
 		(EPHY_EMBED_SHELL (ephy_shell));
@@ -180,55 +155,25 @@ ephy_nautilus_view_instance_init (EphyNautilusView *view)
 	g_object_ref (G_OBJECT (ephy_shell));
 
 	g_signal_connect (view->priv->embed, "ge_link_message",
-			  GTK_SIGNAL_FUNC (gnv_embed_link_message_cb), 
+			  G_CALLBACK (gnv_embed_link_message_cb), 
 			  view);
 	g_signal_connect (view->priv->embed, "ge_location",
-			  GTK_SIGNAL_FUNC (gnv_embed_location_cb), 
+			  G_CALLBACK (gnv_embed_location_cb), 
 			  view);
 	g_signal_connect (view->priv->embed, "ge_title",
-			  GTK_SIGNAL_FUNC (gnv_embed_title_cb), 
+			  G_CALLBACK (gnv_embed_title_cb), 
 			  view);
-/*
-	g_signal_connect (view->priv->embed, "ge_js_status",
-			  GTK_SIGNAL_FUNC (gnv_embed_js_status_cb), 
-			  view);
-	g_signal_connect (view->priv->embed, "ge_progress",
-			  GTK_SIGNAL_FUNC (gnv_embed_progress_cb), 
-			  view);
-	g_signal_connect (view->priv->embed, "ge_net_state",
-			  GTK_SIGNAL_FUNC (gnv_embed_net_state_cb), 
-			  view);
-*/
 	g_signal_connect (view->priv->embed, "ge_new_window",
-			  GTK_SIGNAL_FUNC (gnv_embed_new_window_cb), 
+			  G_CALLBACK (gnv_embed_new_window_cb), 
 			  view);
-/*
-	g_signal_connect (view->priv->embed, "ge_visibility",
-			  GTK_SIGNAL_FUNC (gnv_embed_visibility_cb), 
+	g_signal_connect (view->priv->embed, "ge_dom_mouse_click", 
+			  G_CALLBACK (gnv_embed_dom_mouse_click_cb), 
 			  view);
-	g_signal_connect (view->priv->embed, "ge_destroy_brsr",
-			  GTK_SIGNAL_FUNC (gnv_embed_destroy_brsr_cb), 
+	g_signal_connect (view->priv->embed, "ge_context_menu", 
+			  G_CALLBACK (gnv_embed_context_menu_cb), 
 			  view);
-	g_signal_connect (view->priv->embed, "ge_open_uri",
-			  GTK_SIGNAL_FUNC (gnv_embed_open_uri_cb), 
-			  view);
-	g_signal_connect (view->priv->embed, "ge_size_to",
-			  GTK_SIGNAL_FUNC (gnv_embed_size_to_cb), 
-			  view);
-	g_signal_connect (view->priv->embed, "ge_dom_mouse_click",
-			  GTK_SIGNAL_FUNC (gnv_embed_dom_mouse_click_cb), 
-			  view);
-*/
-	g_signal_connect (view->priv->embed, "ge_dom_mouse_down", 
-			  GTK_SIGNAL_FUNC (gnv_embed_dom_mouse_down_cb), 
-			  view);
-/*
-	g_signal_connect (view->priv->embed, "ge_security_change",
-			  GTK_SIGNAL_FUNC (gnv_embed_security_change_cb), 
-			  view);
-*/
 	g_signal_connect (view->priv->embed, "ge_zoom_change",
-			  GTK_SIGNAL_FUNC (gnv_embed_zoom_change_cb), 
+			  G_CALLBACK (gnv_embed_zoom_change_cb), 
 			  view);
 
 	w = GTK_WIDGET (view->priv->embed);
@@ -250,14 +195,26 @@ ephy_nautilus_view_instance_init (EphyNautilusView *view)
 	bonobo_object_add_interface (BONOBO_OBJECT (view),
 				     BONOBO_OBJECT (view->priv->zoomable));
 
+	/* get zoom levels */
+	levels = g_new0 (float, n_zoom_levels);
+	names = g_new0 (gchar *, n_zoom_levels);
+	for (i = 0; i < n_zoom_levels; i++)
+	{
+		levels[i] = zoom_levels[i].level;
+		names[i] = zoom_levels[i].name;
+	}
+
 	bonobo_zoomable_set_parameters_full (view->priv->zoomable,
 					     1.0,
-					     preferred_zoom_levels [0],
-					     preferred_zoom_levels [NUM_ZOOM_LEVELS - 1],
+					     levels [0],
+					     levels [n_zoom_levels-1],
 					     FALSE, FALSE, TRUE,
-					     preferred_zoom_levels,
-					     preferred_zoom_level_names,
-					     NUM_ZOOM_LEVELS);
+					     levels,
+					     (const gchar **) names,
+					     n_zoom_levels);
+
+	g_free (levels);
+	g_free (names);
 
 	bonobo_object_add_interface (BONOBO_OBJECT (view),
 				     BONOBO_OBJECT (view->priv->zoomable));
@@ -281,7 +238,8 @@ ephy_nautilus_view_instance_init (EphyNautilusView *view)
 			       "nautilus-epiphany-view.xml",
 			       "EphyNautilusView", NULL);
 	p->popup = ephy_embed_popup_control_new (p->control);
-	ephy_embed_popup_connect_verbs (EPHY_EMBED_POPUP (p->popup), p->popup_ui);
+	ephy_embed_popup_control_connect_verbs
+		(EPHY_EMBED_POPUP_CONTROL (p->popup), p->popup_ui);
 	g_object_set_data (G_OBJECT (p->popup), "NautilisView", view);
 
 	bonobo_ui_component_add_verb_list_with_data (p->popup_ui, ephy_popup_verbs, p->popup);
@@ -326,29 +284,19 @@ ephy_nautilus_view_class_init (EphyNautilusViewClass *class)
 	G_OBJECT_CLASS (class)->finalize = ephy_nautilus_view_finalize;
 }
 
-
-
 static gint
-gnv_embed_dom_mouse_down_cb (EphyEmbed *embed,
-			     EphyEmbedEvent *event,
-			     EphyNautilusView *view)
+gnv_embed_dom_mouse_click_cb (EphyEmbed *embed,
+			      EphyEmbedEvent *event,
+			      EphyNautilusView *view)
 {
-	EphyNautilusViewPrivate *p = view->priv;
-	int button;
+	EphyEmbedEventType type;
 	EmbedEventContext context;
 
-	ephy_embed_event_get_mouse_button (event, &button);
-	ephy_embed_event_get_context (event, &context); 
+	ephy_embed_event_get_event_type (event, &type);
+	ephy_embed_event_get_context (event, &context);
 
-	if (button == 2)
-	{
-		ephy_embed_popup_set_event (EPHY_EMBED_POPUP (p->popup), event);
-		ephy_embed_popup_show (EPHY_EMBED_POPUP (p->popup), embed);
-		return TRUE;
-
-	}
-	else if (button == 1
-		 && (context & EMBED_CONTEXT_LINK))
+	if (type == EPHY_EMBED_EVENT_MOUSE_BUTTON2
+	    && (context & EMBED_CONTEXT_LINK))
 	{
 		const GValue *value;
 		const gchar *url;
@@ -364,6 +312,19 @@ gnv_embed_dom_mouse_down_cb (EphyEmbed *embed,
 	return FALSE;
 }
 
+static void
+gnv_embed_context_menu_cb (EphyEmbed *embed,
+			   EphyEmbedEvent *event,
+			   EphyNautilusView *view)
+{
+	EphyNautilusViewPrivate *p = view->priv;
+	EmbedEventContext context;
+
+	ephy_embed_event_get_context (event, &context);
+	ephy_embed_popup_control_set_event (p->popup, event);
+	ephy_embed_popup_control_show (p->popup, embed);
+}
+
 static void
 gnv_embed_link_message_cb (EphyEmbed *embed, const char *message, EphyNautilusView *view)
 {
@@ -374,33 +335,25 @@ gnv_embed_link_message_cb (EphyEmbed *embed, const char *message, EphyNautilusVi
 }
 
 static void
-gnv_embed_location_cb (EphyEmbed *embed, EphyNautilusView *view)
+gnv_embed_location_cb (EphyEmbed *embed, const char *new_uri, EphyNautilusView *view)
 {
-	EphyNautilusViewPrivate *p;
-	const gchar *prefixes_to_ignore[] = 
+	const char *prefixes_to_ignore[] = 
 		{
 			"about:",
 			"javascript:",
 			NULL 
 		};
 	int i = 0;
-	gchar *new_uri;
 
  	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-	p = view->priv;
 	g_return_if_fail (view->priv->embed == embed);
-
-	ephy_embed_get_location (embed, TRUE, &new_uri);
-
  	g_return_if_fail (new_uri != NULL);
 
-
 	/* don't inform nautilus about uris that it can't understand */
 	while (prefixes_to_ignore[i] != NULL)
 	{
-		if (!strncmp (prefixes_to_ignore[i], new_uri, strlen (prefixes_to_ignore[i])))
+		if (strncmp (prefixes_to_ignore[i], new_uri, strlen (prefixes_to_ignore[i])) == 0)
 		{
-			g_free (new_uri);
 			return;
 		}
 		++i;
@@ -408,15 +361,8 @@ gnv_embed_location_cb (EphyEmbed *embed, EphyNautilusView *view)
 
 	nautilus_view_report_location_change (NAUTILUS_VIEW (view), new_uri, NULL, new_uri);
 
- 	/* TODO, FIXME 
-	   nautilus_view_report_redirect (view, p->location, new_uri, NULL, new_uri);
- 	*/
-
-
-	g_free (p->location);
-	p->location = new_uri;
-	
-	
+	g_free (view->priv->location);
+	view->priv->location = g_strdup (new_uri);
 }
 
 static void
@@ -465,8 +411,8 @@ gnv_embed_new_window_cb (EphyEmbed *embed, EphyEmbed **new_embed,
 					  EMBED_CHROME_OPENASPOPUP);
 	}
 	new_tab = ephy_tab_new ();
-	ephy_window_add_tab (window, new_tab, FALSE, FALSE);
-	
+	ephy_window_add_tab (window, new_tab, EPHY_NOTEBOOK_INSERT_LAST, FALSE);
+
 	*new_embed = ephy_tab_get_embed (new_tab);
 }
 
@@ -482,9 +428,9 @@ gnv_bonobo_control_activate_cb (BonoboControl *control, gboolean state, EphyNaut
 						 "nautilus-epiphany-view.xml", "EphyNautilusView");
 		g_return_if_fail (BONOBO_IS_UI_COMPONENT (p->ui));
 		
-		ephy_embed_utils_build_charsets_submenu (p->ui,
-							   CHARSET_MENU_PATH,
-							   (BonoboUIVerbFn) gnv_cmd_set_charset,
+		ephy_embed_utils_build_encodings_submenu (p->ui,
+							   ENCODING_MENU_PATH,
+							   (BonoboUIVerbFn) gnv_cmd_set_encoding,
 							   view);
 
 		bonobo_ui_component_add_verb_list_with_data (p->ui, ephy_verbs, view);
@@ -492,7 +438,7 @@ gnv_bonobo_control_activate_cb (BonoboControl *control, gboolean state, EphyNaut
 }
 
 static EphyNautilusView *
-gnv_view_from_popup (EphyEmbedPopup *popup)
+gnv_view_from_popup (EphyEmbedPopupControl*popup)
 {
 	return g_object_get_data (G_OBJECT (popup), "NautilisView");
 }
@@ -500,7 +446,7 @@ gnv_view_from_popup (EphyEmbedPopup *popup)
 
 static void 
 gnv_popup_cmd_new_window (BonoboUIComponent *uic, 
-			  EphyEmbedPopup *popup, 
+			  EphyEmbedPopupControl*popup, 
 			  const char* verbname)
 {
 	EphyEmbedEvent *info;
@@ -509,7 +455,7 @@ gnv_popup_cmd_new_window (BonoboUIComponent *uic,
 
 	view = gnv_view_from_popup (popup);
 	
-	info = ephy_embed_popup_get_event (popup);
+	info = ephy_embed_popup_control_get_event (popup);
 	
 	ephy_embed_event_get_property (info, "link", &value);
 
@@ -519,7 +465,7 @@ gnv_popup_cmd_new_window (BonoboUIComponent *uic,
 
 static void 
 gnv_popup_cmd_image_in_new_window (BonoboUIComponent *uic, 
-				   EphyEmbedPopup *popup, 
+				   EphyEmbedPopupControl*popup, 
 				   const char* verbname)
 {
 	EphyEmbedEvent *info;
@@ -528,7 +474,7 @@ gnv_popup_cmd_image_in_new_window (BonoboUIComponent *uic,
 
 	view = gnv_view_from_popup (popup);
 	
-	info = ephy_embed_popup_get_event (popup);
+	info = ephy_embed_popup_control_get_event (popup);
 	
 	ephy_embed_event_get_property (info, "image", &value);
 
@@ -538,7 +484,7 @@ gnv_popup_cmd_image_in_new_window (BonoboUIComponent *uic,
 
 static void 
 gnv_popup_cmd_frame_in_new_window (BonoboUIComponent *uic, 
-				   EphyEmbedPopup *popup, 
+				   EphyEmbedPopupControl*popup, 
 				   const char* verbname)
 {
 	EphyEmbedEvent *info;
@@ -547,28 +493,32 @@ gnv_popup_cmd_frame_in_new_window (BonoboUIComponent *uic,
 
 	view = gnv_view_from_popup (popup);
 	
-	info = ephy_embed_popup_get_event (popup);
+	info = ephy_embed_popup_control_get_event (popup);
 	
 	ephy_embed_get_location (view->priv->embed, FALSE, &location);
 
 	nautilus_view_open_location_force_new_window (NAUTILUS_VIEW (view),
 						      location, NULL);
+	g_free (location);
 }
 
 void 
-gnv_cmd_set_charset (BonoboUIComponent *uic, 
-		     EncodingMenuData *data, 
-		     const char* verbname)
+gnv_cmd_set_encoding (BonoboUIComponent *uic, 
+		      EphyNautilusView *view,
+		      const char* verbname)
 {
-	EphyNautilusView *view = data->data;
-	EphyNautilusViewPrivate *p;
+	const char *encoding;
 
 	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
 
-	p = view->priv;
-	
-	LOG ("Set charset %s", data->encoding)
-	ephy_embed_set_charset (p->embed, data->encoding);
+	if (strncmp (verbname, "Encoding", 8) == 0)
+	{
+		encoding = verbname + 8;
+		
+		LOG ("Set encoding %s", encoding)
+
+		ephy_embed_set_encoding (view->priv->embed, encoding);
+	}
 }
 
 static void
@@ -581,11 +531,6 @@ gnv_cmd_file_print (BonoboUIComponent *uic,
 	
 	dialog = print_dialog_new (p->embed, NULL);
 
-	//g_signal_connect (G_OBJECT(dialog),
-	//		  "preview",
-	//		  G_CALLBACK (print_dialog_preview_cb),
-	//		  window);
-
 	ephy_dialog_set_modal (dialog, TRUE);
 	ephy_dialog_show (dialog);
 
@@ -613,33 +558,41 @@ gnv_zoomable_set_zoom_level_cb (BonoboZoomable *zoomable,
 				float level,
 				EphyNautilusView *view)
 {
-	gint zoom = level * 100;
 	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-	if (zoom < 10) return;
-	if (zoom > 1000) return;
-	ephy_embed_zoom_set (view->priv->embed, zoom, TRUE);
+	ephy_embed_zoom_set (view->priv->embed,
+			     ephy_zoom_get_nearest_zoom_level (level), TRUE);
 }
 
 static void
 gnv_zoomable_zoom_in_cb (BonoboZoomable *zoomable,
 			 EphyNautilusView *view)
 {
-	gint zoom;
+	float zoom, new_zoom;
+	gresult rv;
+	
 	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-	ephy_embed_zoom_get (view->priv->embed, &zoom);
-	if (zoom > 990) return;
-	ephy_embed_zoom_set (view->priv->embed, zoom + 10, TRUE);
+
+	rv = ephy_embed_zoom_get (view->priv->embed, &zoom);
+	if (rv == G_FAILED) return;
+
+	new_zoom = ephy_zoom_get_changed_zoom_level (zoom, 1);
+	ephy_embed_zoom_set (view->priv->embed, new_zoom, TRUE);
 }
 
 static void
 gnv_zoomable_zoom_out_cb (BonoboZoomable *zoomable,
 			  EphyNautilusView *view)
 {
-	gint zoom;
+	float zoom, new_zoom;
+	gresult rv;
+		
 	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-	ephy_embed_zoom_get (view->priv->embed, &zoom);
-	if (zoom < 20) return;
-	ephy_embed_zoom_set (view->priv->embed, zoom - 10, TRUE);
+
+	rv = ephy_embed_zoom_get (view->priv->embed, &zoom);
+	if (rv == G_FAILED) return;
+
+	new_zoom = ephy_zoom_get_changed_zoom_level (zoom, -1);
+	ephy_embed_zoom_set (view->priv->embed, new_zoom, TRUE);
 }
 
 static void
@@ -654,301 +607,16 @@ gnv_zoomable_zoom_to_default_cb	(BonoboZoomable *zoomable,
 				 EphyNautilusView *view)
 {
 	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-	ephy_embed_zoom_set (view->priv->embed, 100, TRUE);
+	ephy_embed_zoom_set (view->priv->embed, 1.0, TRUE);
 }
 
 static void
 gnv_embed_zoom_change_cb (EphyNautilusView *embed,
-			  guint new_zoom, 
+			  float new_zoom, 
 			  EphyNautilusView *view)
 {
-	float flevel;
 	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
 	
-	flevel = ((float) new_zoom) / 100.0;
-	
 	bonobo_zoomable_report_zoom_level_changed (view->priv->zoomable,
-						   flevel, NULL);
-	
+						   new_zoom, NULL);
 }
-
-
-#ifdef IM_TOO_LAZY_TO_MOVE_THIS_TO_ANOTHER_FILE
-
-
-/* property bag properties */
-enum {
-	ICON_NAME,
-	COMPONENT_INFO
-};
-
-
-static void
-get_bonobo_properties (BonoboPropertyBag *bag,
-			BonoboArg *arg,
-			guint arg_id,
-			CORBA_Environment *ev,
-			gpointer callback_data)
-{
-	EphyNautilusView *content_view;
-	
-	content_view = (EphyNautilusView*) callback_data;
-
-	switch (arg_id) {
-        	case ICON_NAME:	
-			if (!strncmp (content_view->priv->uri, "man:", 4)) {
-                   		BONOBO_ARG_SET_STRING (arg, "manual");					
-			} else if (!strncmp (content_view->priv->uri, "http:", 5)) {
-                		BONOBO_ARG_SET_STRING (arg, "i-web");					
-			} else if (!strncmp (content_view->priv->uri, "https:", 6)) {
-				/* FIXME: put a nice icon for secure sites */
-                		BONOBO_ARG_SET_STRING (arg, "i-web");					
-			} else {
-                		BONOBO_ARG_SET_STRING (arg, "");					
-                	}
-                	break;
-
-        	case COMPONENT_INFO:
-               		BONOBO_ARG_SET_STRING (arg, "");					
-                 	break;
-        		
-        	default:
-                	g_warning ("Unhandled arg %d", arg_id);
-                	break;
-	}
-}
-
-/* there are no settable properties, so complain if someone tries to set one */
-static void
-set_bonobo_properties (BonoboPropertyBag *bag,
-			const BonoboArg *arg,
-			guint arg_id,
-			CORBA_Environment *ev,
-			gpointer callback_data)
-{
-                g_warning ("Bad Property set on view: property ID %d",
-			   arg_id);
-}
-
-static void
-ephy_nautilus_view_initialize (EphyNautilusView *view)
-{
-
-
-#ifdef NOT_PORTED
-	bonobo_control_set_properties (nautilus_view_get_bonobo_control (view->priv->nautilus_view),
-				       view->priv->property_bag);
-#endif
-	bonobo_property_bag_add (view->priv->property_bag, "icon_name", ICON_NAME, 
-				 BONOBO_ARG_STRING, NULL,
-				 _("name of icon for the mozilla view"), 0);
-	bonobo_property_bag_add (view->priv->property_bag, "summary_info", COMPONENT_INFO,
-				 BONOBO_ARG_STRING, NULL,
-				 _("mozilla summary info"), 0);
-}
-
-
-	/* free the property bag */
-	if (view->priv->property_bag != NULL) {
-		bonobo_object_unref (BONOBO_OBJECT (view->priv->property_bag));
-		view->priv->property_bag = NULL;
-	}
-
-}
-
-
-
-void
-ephy_nautilus_view_report_load_progress (EphyNautilusView *view,
-					   double value)
-{
-	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-
-	if (value < 0.0) value = 0.0;
-	if (value > 1.0) value = 1.0;
-	
-	nautilus_view_report_load_progress (view->priv->nautilus_view, value);
-}
-
-/***********************************************************************************/
-
-/**
- * vfs_open_cb
- *
- * Callback for gnome_vfs_async_open. Attempt to read data from handle
- * and pass to mozilla streaming callback.
- * 
- **/
-static void
-vfs_open_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
-{
-	EphyNautilusView *view = data;
-
-	LOG ("+%s GnomeVFSResult: %u", G_GNUC_FUNCTION, (unsigned)result)
-
-	if (result != GNOME_VFS_OK)
-	{
-		gtk_moz_embed_close_stream (GTK_MOZ_EMBED (view->priv->embed->mozembed));
-		/* NOTE: the view may go away after a call to report_load_failed */
-		LOG (">nautilus_view_report_load_failed")
-		nautilus_view_report_load_failed (view->priv->nautilus_view);
-	} else {
-		if (view->priv->vfs_read_buffer == NULL) {
-			view->priv->vfs_read_buffer = g_malloc (VFS_READ_BUFFER_SIZE);
-		}
-		gtk_moz_embed_open_stream (GTK_MOZ_EMBED (view->priv->embed->mozembed), "file:///", "text/html");
-		gnome_vfs_async_read (handle, view->priv->vfs_read_buffer, VFS_READ_BUFFER_SIZE, vfs_read_cb, view);
-	}
-	LOG ("-%s", G_GNUC_FUNCTION);
-}
-
-/**
- * vfs_read_cb:
- *
- * Read data from buffer and copy into mozilla stream.
- **/
-
-static void
-vfs_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer buffer,
-		   GnomeVFSFileSize bytes_requested,
-		   GnomeVFSFileSize bytes_read,
-		   gpointer data)
-{
-	EphyNautilusView *view = data;
-
-	LOG ("+%s %ld/%ld bytes", G_GNUC_FUNCTION, (long)bytes_requested, (long) bytes_read)
-
-	if (bytes_read != 0) {
-		gtk_moz_embed_append_data (GTK_MOZ_EMBED (view->priv->embed->mozembed), buffer, bytes_read);
-	}
-
-	if (bytes_read == 0 || result != GNOME_VFS_OK) {
-		gtk_moz_embed_close_stream (GTK_MOZ_EMBED (view->priv->embed->mozembed));
-		view->priv->vfs_handle = NULL;
-		g_free (view->priv->vfs_read_buffer);
-		view->priv->vfs_read_buffer = NULL;
-		
-		gnome_vfs_async_close (handle, (GnomeVFSAsyncCloseCallback) gtk_true, NULL);
-
-		LOG (">nautilus_view_report_load_complete")
-		nautilus_view_report_load_complete (view->priv->nautilus_view);
-
-		LOG ("=%s load complete", G_GNUC_FUNCTION)
-    	} else {
-		gnome_vfs_async_read (handle, view->priv->vfs_read_buffer, VFS_READ_BUFFER_SIZE, vfs_read_cb, view);
-	}
-
-	LOG ("-%s", G_GNUC_FUNCTION)
-}
-
-/***********************************************************************************/
-
-static void
-cancel_pending_vfs_operation (EphyNautilusView *view)
-{
-	if (view->priv->vfs_handle != NULL) {
-		gnome_vfs_async_cancel (view->priv->vfs_handle);
-		gtk_moz_embed_close_stream (GTK_MOZ_EMBED (view->priv->embed->mozembed));
-	}
-
-	view->priv->vfs_handle = NULL;
-	g_free (view->priv->vfs_read_buffer);
-	view->priv->vfs_read_buffer = NULL;
-}
-
-
-/* this takes a "nautilus" uri, not a "mozilla" uri and uses (sometimes) GnomeVFS */
-static void
-navigate_mozilla_to_nautilus_uri (EphyNautilusView *view,
-			 	  const char *uri)
-{
-	char *old_uri;
-
-	cancel_pending_vfs_operation (view);
-	
-	if (!GTK_WIDGET_REALIZED (view->priv->embed->mozembed)) {
-		
-		/* Doing certain things to gtkmozembed before
-		 * the widget has realized (specifically, opening
-		 * content streams) can cause crashes.  To avoid
-		 * this, we postpone all navigations
-		 * until the widget has realized (we believe
-		 * premature realization may cause other issues)
-		 */
-		
-		LOG ("=%s: Postponing navigation request to widget realization", G_GNUC_FUNCTION)
-		/* Note that view->priv->uri is still set below */
-	} else {
-		if (should_mozilla_load_uri_directly (uri)) {
-
-			/* See if the current URI is the same as what mozilla already
-			 * has.  If so, issue a reload rather than a load.
-			 * We ask mozilla for it's uri rather than using view->priv->uri because,
-			 * from time to time, our understanding of mozilla's URI can become inaccurate
-			 * (in particular, certain errors may cause embedded mozilla to not change
-			 * locations)
-			 */
-
-			old_uri = view->priv->embed->location;
-
-			if (old_uri != NULL && uris_identical (uri, old_uri)) {
-				LOG ("=%s uri's identical, telling ephy to reload", G_GNUC_FUNCTION)
-				embed_reload (view->priv->embed,
-					      GTK_MOZ_EMBED_FLAG_RELOADBYPASSCACHE);
-			} else {
-				embed_load_url (view->priv->embed, uri);
-			}
-
-		} else {
-			LOG ("=%s loading URI via gnome-vfs", G_GNUC_FUNCTION)
-			gnome_vfs_async_open (&(view->priv->vfs_handle), uri,
-					      GNOME_VFS_OPEN_READ, GNOME_VFS_PRIORITY_DEFAULT, 
-					      vfs_open_cb, view);
-		}
-	}
-
-	g_free (view->priv->uri);
-	view->priv->uri = g_strdup (uri);
-
-	LOG ("=%s current URI is now '%s'", G_GNUC_FUNCTION, view->priv->uri)
-}
-
-/*
- * This a list of URI schemes that mozilla should load directly, rather than load through gnome-vfs
- */
-static gboolean
-should_mozilla_load_uri_directly (const char *uri)
-{
-	static const char *handled_by_mozilla[] =
-	{
-		"http",
-		"file",
-		"toc",
-		"man",
-		"info",
-		"ghelp",
-		"gnome-help",
-		"https",
-		NULL
-	};
-	gint i;
-	gint uri_length;
-
-	if (uri == NULL) return FALSE;
-
-	uri_length = strlen (uri);
-
-	for (i = 0; handled_by_mozilla[i] != NULL; i++)
-	{
-		const gchar *current = handled_by_mozilla[i];
-		gint current_length = strlen (current);
-		if ((uri_length >= current_length) 
-		    && (!strncasecmp (uri, current, current_length))) 
-			return TRUE;
-	}
-	return FALSE;
-}
-
-
-
-#endif
