@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.73 2003/07/20 11:05:16 mpeseng Exp $
+ *  $Id: window-commands.c,v 1.74 2003/08/05 22:55:13 chpe Exp $
  */
 
 #include <config.h>
@@ -157,7 +157,14 @@ window_cmd_go_home (EggAction *action,
 
 	location = eel_gconf_get_string (CONF_GENERAL_HOMEPAGE);
 
-	ephy_window_load_url (window, location ? location : "about:blank");
+	if (location == NULL || location[0] == '\0')
+	{
+		g_free (location);
+
+		location = g_strdup ("about:blank");
+	}
+
+	ephy_window_load_url (window, location);
 
 	g_free (location);
 }
